package net.wanji.web.common.exception;

import lombok.Getter;
import lombok.Setter;
import net.wanji.web.common.enums.BaseInfoInterface;
import net.wanji.web.common.enums.ResultEnum;

/**
 * @author wuxiaokai
 * @date 2022/11/21 9:38:54
 */
@Setter
@Getter
public class CrossException extends RuntimeException {
    private static final long serialVersionUID = 9081671784110014059L;

    /**
     * 错误码
     */
    protected Integer errorCode;
    /**
     * 错误信息
     */
    protected String errorMsg;

    public CrossException() {
        this(ResultEnum.INTERNAL_SERVER_ERROR.getResultCode(), ResultEnum.INTERNAL_SERVER_ERROR.getResultMsg());
    }

    public CrossException(BaseInfoInterface errorInfoInterface) {
        super(errorInfoInterface.getResultMsg());
        this.errorCode = errorInfoInterface.getResultCode();
        this.errorMsg = errorInfoInterface.getResultMsg();
    }

    public CrossException(BaseInfoInterface errorInfoInterface, Throwable cause) {
        super(errorInfoInterface.getResultMsg(), cause);
        this.errorCode = errorInfoInterface.getResultCode();
        this.errorMsg = errorInfoInterface.getResultMsg();
    }

    public CrossException(String errorMsg) {
        this(ResultEnum.INTERNAL_SERVER_ERROR.getResultCode(), errorMsg);
    }

    public CrossException(Integer errorCode, String errorMsg) {
        this(errorCode, errorMsg, null);
    }

    public CrossException(Integer errorCode, String errorMsg, Throwable cause) {
        super(errorMsg, cause);
        this.errorCode = errorCode;
        this.errorMsg = errorMsg;
    }

    @Override
    public Throwable fillInStackTrace() {
        return this;
    }
}
