package net.wanji.web.controller;

import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import net.wanji.common.framework.rest.JsonViewObject;
import net.wanji.databus.bo.AreaDetailBO;
import net.wanji.databus.bo.AreaIdBO;
import net.wanji.databus.vo.AreaDetailVO;
import net.wanji.databus.vo.AreaInfoVO;
import net.wanji.databus.vo.CrossIdAndNameVO;
import net.wanji.web.bo.AddOrUpdateAreaBO;
import net.wanji.web.bo.ControlModeBO;
import net.wanji.web.bo.PolygonBO;
import net.wanji.web.bo.SpecialServiceRouteBO;
import net.wanji.web.service.impl.CrossManageServiceImpl;
import net.wanji.web.vo.*;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.ws.rs.core.MediaType;
import java.util.List;

/**
 * 路口管理
 *
 * @author Kent HAN
 */
@Api(value = "CrossManageController", description = "路口管理")
@RequestMapping("/crossManage")
@RestController
public class CrossManageController {

    private final CrossManageServiceImpl crossManageService;

    public CrossManageController(CrossManageServiceImpl crossManageService) {
        this.crossManageService = crossManageService;
    }

    @ApiOperation(value = "框选路口", notes = "框选路口", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/selectCrossesByPolygon",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = JsonViewObject.class),
    })
    public JsonViewObject selectCrossesByPolygon(@RequestBody PolygonBO polygonBO) {
        List<CrossIdAndNameVO> res = crossManageService.selectCrossesByPolygon(polygonBO);
        return JsonViewObject.newInstance().success(res);
    }

    @ApiOperation(value = "点选路口", notes = "点选路口", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/selectCrossesByStartEnd",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = JsonViewObject.class),
    })
    public JsonViewObject selectCrossesByStartEnd(@RequestBody SpecialServiceRouteBO specialServiceRouteBO) {
        SelectCrossesByStartEndVO res = crossManageService.selectCrossesByStartEnd(specialServiceRouteBO);
        return JsonViewObject.newInstance().success(res);
    }

    @ApiOperation(value = "区域新增/修改", notes = "区域新增/修改，传ID为修改，不传ID为新增", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/addOrUpdateArea",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = AreaIdBO.class),
    })
    public JsonViewObject addOrUpdateArea(@RequestBody AddOrUpdateAreaBO addOrUpdateAreaBO) {
        AreaIdBO res = crossManageService.addOrUpdateArea(addOrUpdateAreaBO);
        return JsonViewObject.newInstance().success(res);
    }

    @ApiOperation(value = "删除区域", notes = "删除区域", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/deleteArea",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = JsonViewObject.class),
    })
    public JsonViewObject deleteArea(@RequestBody AreaIdBO areaIdBO) {
        crossManageService.deleteArea(areaIdBO);
        return JsonViewObject.newInstance().success();
    }

    @ApiOperation(value = "区域列表", notes = "区域列表", produces = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/listArea", produces = MediaType.APPLICATION_JSON)
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = ListAreaVO.class),
    })
    public JsonViewObject listArea() {
        ListAreaVO listAreaVO = crossManageService.listArea();
        return JsonViewObject.newInstance().success(listAreaVO);
    }

    @ApiOperation(value = "区域详情", notes = "区域详情", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/areaDetail",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = AreaDetailVO.class),
    })
    public JsonViewObject areaDetail(@RequestBody AreaDetailBO areaDetailBO) throws Exception {
        PageInfo<AreaDetailVO> res = crossManageService.areaDetail(areaDetailBO);
        return JsonViewObject.newInstance().success(res);
    }

    @ApiOperation(value = "区域信息", notes = "区域信息", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/areaInfo",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = AreaInfoVO.class),
    })
    public JsonViewObject areaInfo(@RequestBody AreaIdBO areaIdBO) {
        AreaInfoVO res = crossManageService.areaInfo(areaIdBO);
        return JsonViewObject.newInstance().success(res);
    }

    @ApiOperation(value = "控制模式下拉框", notes = "控制模式下拉框", produces = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/controlModeMenu", produces = MediaType.APPLICATION_JSON)
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = ControlModeVO.class),
    })
    public JsonViewObject controlModeMenu() {
        List<ControlModeVO> res = crossManageService.controlModeMenu();
        return JsonViewObject.newInstance().success(res);
    }

    @ApiOperation(value = "修改控制模式", notes = "修改控制模式", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/updateControlMode",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = JsonViewObject.class),
    })
    public JsonViewObject updateControlMode(@RequestBody ControlModeBO controlModeBO) {
        crossManageService.updateControlMode(controlModeBO);
        return JsonViewObject.newInstance().success();
    }

}