package net.wanji.web.controller;

import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import net.wanji.common.annotation.aspect.AspectLog;
import net.wanji.common.enums.BaseEnum;
import net.wanji.common.framework.Constants;
import net.wanji.common.framework.rest.JsonViewObject;
import net.wanji.common.utils.tool.DateUtil;
import net.wanji.databus.bo.CrossIdBO;
import net.wanji.databus.dao.entity.CrossSyncLogPO;
import net.wanji.databus.dao.mapper.CrossSyncLogMapper;
import net.wanji.web.dto.*;
import net.wanji.web.po.RingPhasePO;
import net.wanji.web.service.impl.PlanSendServiceImpl;
import net.wanji.web.vo.PhaseListByTimeVO;
import net.wanji.web.vo.PhaseListVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.Date;
import java.util.List;

/**
 * @author hanbing
 * @date 2023/01/04 16:10
 */
@Api(value = "PlanSendController", description = "方案下发")
@RequestMapping("/planSend")
@RestController
@SuppressWarnings("all")
public class PlanSendController {
    private final PlanSendServiceImpl planSendService;

    @Autowired
    private CrossSyncLogMapper crossSyncLogMapper;

    public PlanSendController(PlanSendServiceImpl planSendService) {
        this.planSendService = planSendService;
    }

    @AspectLog(description = "方案下发", operationType = BaseEnum.OperationTypeEnum.UPDATE)
    @ApiOperation(value = "方案下发", notes = "时间表下发")
    @PostMapping("/scheduleSend")
    public JsonViewObject timeTableSend(@RequestBody ScheduleIdDTO scheduleIdDTO) {
        JsonViewObject jsonViewObject = planSendService.scheduleSend(scheduleIdDTO);
        return jsonViewObject;
    }

    @AspectLog(description = "强制方案", operationType = BaseEnum.OperationTypeEnum.UPDATE)
    @ApiOperation(value = "强制方案", notes = "强制方案")
    @PostMapping("/schemeSend")
    public JsonViewObject schemeSend(@RequestBody SchemeIdDTO schemeIdDTO) {
        JsonViewObject jsonViewObject = planSendService.schemeSend(schemeIdDTO);
        return jsonViewObject;
    }

    @AspectLog(description = "模式切换-中心控制-步进", operationType = BaseEnum.OperationTypeEnum.UPDATE)
    @ApiOperation(value = "模式切换-中心控制-步进", notes = "模式切换-中心控制-步进")
    @PostMapping("/nextStep")
    public JsonViewObject nextStep(@RequestBody CrossIdBO crossIdBO) {
        JsonViewObject jsonViewObject = planSendService.nextStep(crossIdBO);
        return jsonViewObject;
    }

    @AspectLog(description = "模式切换-中心控制-相位锁定", operationType = BaseEnum.OperationTypeEnum.UPDATE)
    @ApiOperation(value = "模式切换-中心控制-相位锁定", notes = "模式切换-中心控制-相位锁定")
    @PostMapping("/lockPhase")
    public JsonViewObject lockPhase(@RequestBody CrossIdAndPhaseIdsDTO crossIdAndPhaseIdsDTO) {
        JsonViewObject jsonViewObject = planSendService.lockPhase(crossIdAndPhaseIdsDTO);
        return jsonViewObject;
    }

    @AspectLog(description = "模式切换-中心控制-全红控制", operationType = BaseEnum.OperationTypeEnum.UPDATE)
    @ApiOperation(value = "模式切换-中心控制-全红控制", notes = "模式切换-中心控制-全红控制")
    @PostMapping("/allRedControl")
    public JsonViewObject allRedControl(@RequestBody CrossIdBO crossIdBO) {
        JsonViewObject jsonViewObject = planSendService.allRedControl(crossIdBO);
        return jsonViewObject;
    }

    @AspectLog(description = "模式切换-中心控制-黄闪控制", operationType = BaseEnum.OperationTypeEnum.UPDATE)
    @ApiOperation(value = "模式切换-中心控制-黄闪控制", notes = "模式切换-中心控制-黄闪控制")
    @PostMapping("/yellowLightControl")
    public JsonViewObject yellowLightControl(@RequestBody CrossIdBO crossIdBO) {
        JsonViewObject jsonViewObject = planSendService.yellowLightControl(crossIdBO);
        return jsonViewObject;
    }

    @AspectLog(description = "模式切换-中心控制-恢复", operationType = BaseEnum.OperationTypeEnum.UPDATE)
    @ApiOperation(value = "模式切换-中心控制-恢复", notes = "模式切换-中心控制-恢复")
    @PostMapping("/restore")
    public JsonViewObject restore(@RequestBody CrossIdAndPhaseIdsDTO crossIdAndPhaseIdsDTO) {
        JsonViewObject jsonViewObject = planSendService.restore(crossIdAndPhaseIdsDTO);
        return jsonViewObject;
    }

    @AspectLog(description = "信号机方案同步", operationType = BaseEnum.OperationTypeEnum.UPDATE)
    @ApiOperation(value = "信号机方案同步", notes = "信号机方案同步")
    @PostMapping("/syncScheme")
    public JsonViewObject syncScheme(@RequestBody CrossIdBO crossIdBO) throws Exception {
        JsonViewObject jsonViewObject = null;
        CrossSyncLogPO crossSyncLogPO = new CrossSyncLogPO();
        String dt = DateUtil.format(new Date(), Constants.DATE_FORMAT.E_DATE_FORMAT_DAY);
        crossSyncLogPO.setCrossId(crossIdBO.getCrossId());
        crossSyncLogPO.setType(2);
        crossSyncLogPO.setDt(dt);
        try {
            jsonViewObject = planSendService.syncScheme(crossIdBO);
            crossSyncLogPO.setResultCode(jsonViewObject.getCode());
            crossSyncLogPO.setResultMessage(JSON.toJSONString(jsonViewObject));
        } catch (Exception e) {
            jsonViewObject = JsonViewObject.newInstance();
            jsonViewObject.setCode(500);
            jsonViewObject.setMessage(e.getMessage());
            crossSyncLogPO.setResultCode(500);
            crossSyncLogPO.setResultMessage("手动同步报错");
        }
        crossSyncLogMapper.insert(crossSyncLogPO);
        return jsonViewObject;
    }

    @AspectLog(description = "信号机方案同步-一键同步所有路口", operationType = BaseEnum.OperationTypeEnum.UPDATE)
    @ApiOperation(value = "信号机方案同步-一键同步所有路口", notes = "信号机方案同步-一键同步所有路口")
    @PostMapping("/syncAllCross")
    public JsonViewObject syncAllCross() throws Exception {
        JsonViewObject jsonViewObject = null;
        jsonViewObject = JsonViewObject.newInstance();
        try {
            planSendService.syncAllCross(3);
            return JsonViewObject.newInstance().success("全量同步成功");
        } catch (Exception e) {
            return JsonViewObject.newInstance().fail("全量同步失败");

        }

    }

    @AspectLog(description = "信号机调度日计划同步", operationType = BaseEnum.OperationTypeEnum.UPDATE)
    @ApiOperation(value = "信号机调度日计划同步", notes = "信号机调度日计划同步")
    @PostMapping("/syncSchedules")
    public JsonViewObject syncSchedules(@RequestBody CrossIdBO crossIdBO) throws Exception {
//        planSendService.syncSchedules(crossIdBO.getCrossId());
        return JsonViewObject.newInstance().success("");
    }

    @AspectLog(description = "根据当前时间返回相位列表", operationType = BaseEnum.OperationTypeEnum.UPDATE)
    @ApiOperation(value = "根据当前时间返回相位列表", notes = "根据当前时间返回相位列表")
    @PostMapping("/phaseListByTime")
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = PhaseListByTimeVO.class),
    })
    public JsonViewObject phaseListByTime(@RequestBody CrossIdAndTimeDTO crossIdAndTimeDTO) {
        PhaseListByTimeVO phaseListByTimeVO = planSendService.phaseListByTime(crossIdAndTimeDTO);
        JsonViewObject jsonViewObject = JsonViewObject.newInstance();

        return jsonViewObject.success(phaseListByTimeVO);
    }

    @AspectLog(description = "根据当前时间返回相位列表（单环）", operationType = BaseEnum.OperationTypeEnum.UPDATE)
    @ApiOperation(value = "根据当前时间返回相位列表（单环）", notes = "根据当前时间返回相位列表（单环）")
    @PostMapping("/phaseListByTimeSingleRing")
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = SaveSchemeConfigDTO.PhaseListElement.class),
    })
    public JsonViewObject phaseListByTimeSingleRing(@RequestBody CrossIdAndTimeDTO crossIdAndTimeDTO) {
        List<SaveSchemeConfigDTO.PhaseListElement> phaseListByTime
                = planSendService.phaseListByTimeSingleRing(crossIdAndTimeDTO);
        JsonViewObject jsonViewObject = JsonViewObject.newInstance();

        return jsonViewObject.success(phaseListByTime);

    }

    @AspectLog(description = "根据当前时间返回相位列表（单环）-新增黃闪模式", operationType = BaseEnum.OperationTypeEnum.UPDATE)
    @ApiOperation(value = "根据当前时间返回相位列表（单环）-新增黃闪模式", notes = "根据当前时间返回相位列表（单环）-新增黃闪模式")
    @PostMapping("/phaseListByTimeSingleRingControlMode")
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = SaveSchemeConfigDTO.PhaseListElement.class),
    })
    public JsonViewObject phaseListByTimeSingleRingControlMode(@RequestBody CrossIdAndTimeDTO crossIdAndTimeDTO) {
        PhaseListVO phaseListVO
                = planSendService.phaseListByTimeSingleRingControlMode(crossIdAndTimeDTO);
        JsonViewObject jsonViewObject = JsonViewObject.newInstance();

        return jsonViewObject.success(phaseListVO);

    }

    @AspectLog(description = "根据当前时间返回相位列表-方案优化对比", operationType = BaseEnum.OperationTypeEnum.UPDATE)
    @ApiOperation(value = "根据当前时间返回相位列表-方案优化对比）", notes = "根据当前时间返回相位列表-方案优化对比")
    @PostMapping("/phaseListByTimeSingleRingNew")
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = SaveSchemeConfigDTO.PhaseListElement.class),
    })
    public JsonViewObject phaseListByTimeSingleRingNew(@RequestBody CrossIdAndTimeDTO crossIdAndTimeDTO) {
        RingPhasePO ringPhasePO = planSendService.phaseListByTimeSingleRingNew(crossIdAndTimeDTO);
        JsonViewObject jsonViewObject = JsonViewObject.newInstance();

        return jsonViewObject.success(ringPhasePO);
    }

    @AspectLog(description = "根据当前时间返回相位列表-方案优化对比-新增黃闪模式", operationType = BaseEnum.OperationTypeEnum.UPDATE)
    @ApiOperation(value = "根据当前时间返回相位列表-方案优化对比-新增黃闪模式）", notes = "根据当前时间返回相位列表-方案优化对比-新增黃闪模式")
    @PostMapping("/phaseListByTimeSingleRingNewControlMode")
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = SaveSchemeConfigDTO.PhaseListElement.class),
    })
    public JsonViewObject phaseListByTimeSingleRingNewControlMode(@RequestBody CrossIdAndTimeDTO crossIdAndTimeDTO) {
        RingPhasePO ringPhasePO = planSendService.phaseListByTimeSingleRingNew(crossIdAndTimeDTO);
        JsonViewObject jsonViewObject = JsonViewObject.newInstance();

        return jsonViewObject.success(ringPhasePO);
    }

    @AspectLog(description = "根据路口号和时间(据当前时间半小时)返回相位列表-方案优化对比", operationType = BaseEnum.OperationTypeEnum.UPDATE)
    @ApiOperation(value = "根据路口号和时间(据当前时间半小时)返回相位列表-方案优化对比）", notes = "根据路口号和时间(据当前时间半小时)返回相位列表-方案优化对比")
    @PostMapping("/phaseListByTimeRingNew")
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = SaveSchemeConfigDTO.PhaseListElement.class),
    })
    public JsonViewObject phaseListByTimeRingNew(@RequestBody CrossIdAndTimeDTO crossIdAndTimeDTO) {
        RingPhasePO ringPhasePO = planSendService.phaseListByTimeRingNew(crossIdAndTimeDTO);
        JsonViewObject jsonViewObject = JsonViewObject.newInstance();

        return jsonViewObject.success(ringPhasePO);
    }

    @AspectLog(description = "下发数据到UTC", operationType = BaseEnum.OperationTypeEnum.UPDATE)
    @ApiOperation(value = "下发数据到UTC", notes = "下发数据到UTC")
    @PostMapping("/saveToUtc")
    public JsonViewObject saveToUtc(String crossId) throws Exception {
        return planSendService.saveToUtc(crossId);
    }
}
