package net.wanji.web.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import net.wanji.common.annotation.aspect.AspectLog;
import net.wanji.common.enums.BaseEnum;
import net.wanji.common.framework.rest.JsonViewObject;
import net.wanji.web.common.util.date.DateStyle;
import net.wanji.web.common.util.date.DateUtils;
import net.wanji.web.service.SignalEvaluateService;
import net.wanji.web.vo.signalEvaluate.FlowQueueInVO;
import net.wanji.web.vo.signalEvaluate.FlowQueueOutVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.ws.rs.core.MediaType;
import java.text.ParseException;
import java.util.Date;

/**
 * 信号评价
 *
 * @author Kent HAN
 * @date 2022/11/3 15:52
 */
@Api(value = "SignalEvaluateController", description = "信号评价")
@RequestMapping("/signalEvaluate")
@RestController
public class SignalEvaluateController extends BaseController{
    @Autowired
    SignalEvaluateService signalEvaluateService;

    @AspectLog(description = "流量、排队折线图", operationType = BaseEnum.OperationTypeEnum.QUERY)
    @ApiOperation(value = "流量、排队折线图", notes = "流量、排队折线图", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/flowQueue",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    public JsonViewObject flowQueue(@RequestBody FlowQueueInVO flowQueueInVO) throws ParseException {
        String adCode = flowQueueInVO.getAdCode();
        String crossId = flowQueueInVO.getCrossId();
        String currentTimeStr = flowQueueInVO.getCurrentTime();
        Date currentTime = DateUtils.getDateFormat(DateStyle.YYYY_MM_DD_HH_MM_SS.getValue()).parse(currentTimeStr);
        Integer timeType = flowQueueInVO.getTimeType();
        Integer dataType = flowQueueInVO.getDataType();
        FlowQueueOutVO flowQueueOutVO = signalEvaluateService.flowQueue(adCode, crossId, currentTime, timeType, dataType);
        JsonViewObject jsonViewObject = JsonViewObject.newInstance();

        return jsonViewObject.success(flowQueueOutVO);
    }
}
