package net.wanji.web.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import net.wanji.common.annotation.aspect.AspectLog;
import net.wanji.common.enums.BaseEnum;
import net.wanji.common.framework.rest.JsonViewObject;
import net.wanji.databus.vo.LockControlVO;
import net.wanji.web.bo.*;
import net.wanji.web.service.SpecialServiceService;
import net.wanji.web.vo.specialService.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import javax.ws.rs.core.MediaType;
import java.util.List;

/**
 * 快速特勤
 *
 * @author Kent HAN
 * @date 2022/11/8 10:57
 */
@Api(value = "SpecialServiceController", description = "特勤管理")
@RequestMapping("/specialService")
@RestController
public class SpecialServiceController {
    @Autowired
    SpecialServiceService specialServiceService;

    @AspectLog(description = "查询地图点位是否可选", operationType = BaseEnum.OperationTypeEnum.QUERY)
    @ApiOperation(value = "查询地图点位是否可选", notes = "查询地图点位是否可选", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/isValidPoint",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    public JsonViewObject isValidPoint(@RequestBody IsValidPointBO isValidPointBO) {
        specialServiceService.isValidPoint(isValidPointBO);
        return JsonViewObject.newInstance().success();
    }

    @AspectLog(description = "备选路线推送", operationType = BaseEnum.OperationTypeEnum.QUERY)
    @ApiOperation(value = "备选路线推送", notes = "备选路线推送", response = RouteElementVO.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/specialServiceRoute",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    public JsonViewObject specialServiceRoute(@RequestBody SpecialServiceRouteBO specialServiceRouteBO) {
        List<List<RouteElementVO>> res = specialServiceService.specialServiceRoute(specialServiceRouteBO);
        return JsonViewObject.newInstance().success(res);
    }

    @AspectLog(description = "添加/编辑特勤", operationType = BaseEnum.OperationTypeEnum.QUERY)
    @ApiOperation(value = "添加/编辑特勤", notes = "添加/编辑特勤", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/addOrUpdateSpecialService",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    public JsonViewObject addOrUpdateSpecialService(@RequestBody @Valid AddSpecialServiceBO addSpecialServiceBO) {
        specialServiceService.addOrUpdateSpecialService(addSpecialServiceBO);
        return JsonViewObject.newInstance().success();
    }

    @AspectLog(description = "快速特勤列表", operationType = BaseEnum.OperationTypeEnum.QUERY)
    @ApiOperation(value = "快速特勤列表", notes = "快速特勤列表", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON)
    @GetMapping(value = "/listSpecialServices",
            produces = MediaType.APPLICATION_JSON)
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = ListSpecialServicesVO.class),
    })
    public JsonViewObject listSpecialServices() {
        List<ListSpecialServicesVO> listSpecialServicesVOList = specialServiceService.listSpecialServices();
        return JsonViewObject.newInstance().success(listSpecialServicesVOList);
    }

    @AspectLog(description = "删除特勤", operationType = BaseEnum.OperationTypeEnum.DELETE)
    @ApiOperation(value = "删除特勤", notes = "删除特勤", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/deleteSpecialService",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    public JsonViewObject deleteSpecialService(@RequestBody SpecialServiceIdBO specialServiceIdBO) {
        Integer id = specialServiceIdBO.getId();
        specialServiceService.deleteSpecialService(id);
        return JsonViewObject.newInstance().success();
    }

    @AspectLog(description = "特勤详情", operationType = BaseEnum.OperationTypeEnum.UPDATE)
    @ApiOperation(value = "特勤详情", notes = "特勤详情", response = SpecialServiceDetailVO.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/specialServiceDetail",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    public JsonViewObject specialServiceDetail(@RequestBody SpecialServiceIdBO specialServiceIdBO) {
        SpecialServiceDetailVO specialServiceDetailVO = specialServiceService.specialServiceDetail(specialServiceIdBO);
        return JsonViewObject.newInstance().success(specialServiceDetailVO);
    }

    @AspectLog(description = "修改特勤详情", operationType = BaseEnum.OperationTypeEnum.UPDATE)
    @ApiOperation(value = "修改特勤详情", notes = "修改特勤详情", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/updateSpecialServiceDetail",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    public JsonViewObject updateSpecialServiceDetail(@RequestBody UpdateSpecialServiceBO updateSpecialServiceBO) {
        specialServiceService.updateSpecialServiceDetail(updateSpecialServiceBO);
        return JsonViewObject.newInstance().success();
    }

    @AspectLog(description = "批量锁定/解锁", operationType = BaseEnum.OperationTypeEnum.UPDATE)
    @ApiOperation(value = "批量锁定/解锁", notes = "批量锁定/解锁", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/batchLock",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    public JsonViewObject batchLock(@RequestBody BatchLockBO batchLockBO) {
        specialServiceService.batchLock(batchLockBO);
        return JsonViewObject.newInstance().success();
    }

    @AspectLog(description = "获取路口驶入方向列表", operationType = BaseEnum.OperationTypeEnum.UPDATE)
    @ApiOperation(value = "获取路口驶入方向列表", notes = "获取路口驶入方向列表", response = SpecialDirListVO.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/getInDirList",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    public JsonViewObject getInDirList(@RequestBody List<CrossIdBO> crossIdBOList) {
        List<SpecialDirListVO> specialDirListVOList = specialServiceService.getInDirList(crossIdBOList);
        return JsonViewObject.newInstance().success(specialDirListVOList);
    }

    @AspectLog(description = "获取路口驶出方向列表", operationType = BaseEnum.OperationTypeEnum.UPDATE)
    @ApiOperation(value = "获取路口驶出方向列表", notes = "获取路口驶出方向列表", response = SpecialDirListVO.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/getOutDirList",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    public JsonViewObject getOutDirList(@RequestBody List<CrossIdBO> crossIdBOList) {
        List<SpecialDirListVO> specialDirListVOList = specialServiceService.getOutDirList(crossIdBOList);
        return JsonViewObject.newInstance().success(specialDirListVOList);
    }

    @AspectLog(description = "分组列表", operationType = BaseEnum.OperationTypeEnum.UPDATE)
    @ApiOperation(value = "分组列表", notes = "分组列表", response = GroupListVO.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/groupList",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    public JsonViewObject groupList(@RequestBody SpecialServiceIdBO specialServiceIdBO) {
        GroupListVO groupListVO = specialServiceService.groupList(specialServiceIdBO);
        return JsonViewObject.newInstance().success(groupListVO);
    }

    @AspectLog(description = "修改分组", operationType = BaseEnum.OperationTypeEnum.UPDATE)
    @ApiOperation(value = "修改分组", notes = "修改分组", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/updateGroup",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    public JsonViewObject updateGroup(@RequestBody GroupListVO groupListVO) {
        specialServiceService.updateGroup(groupListVO);
        return JsonViewObject.newInstance().success();
    }

    @AspectLog(description = "删除分组", operationType = BaseEnum.OperationTypeEnum.UPDATE)
    @ApiOperation(value = "删除分组", notes = "删除分组", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/deleteGroup",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    public JsonViewObject deleteGroup(@RequestBody GroupNameBO groupNameBO) {
        specialServiceService.deleteGroup(groupNameBO);
        return JsonViewObject.newInstance().success();
    }

    @AspectLog(description = "自动解锁", operationType = BaseEnum.OperationTypeEnum.UPDATE)
    @ApiOperation(value = "自动解锁", notes = "自动解锁", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/autoUnlock",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    public JsonViewObject autoUnlock(@RequestBody GroupListVO groupListVO) {
        specialServiceService.autoUnlock(groupListVO);
        return JsonViewObject.newInstance().success();
    }

}
