package net.wanji.web.controller.base;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import net.wanji.common.framework.rest.JsonViewObject;
import net.wanji.databus.dao.entity.*;
import net.wanji.databus.po.BaseCrossInfoPO;
import net.wanji.databus.po.CrossBaseLaneInfoPO;
import net.wanji.databus.po.CrossTurnInfoPO;
import net.wanji.web.service.BaseInfoService;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import javax.ws.rs.core.MediaType;
import java.util.List;

/**
 * @author duanruiming
 * @date 2024/11/13 20:30
 */
@Api(value = "CrossBaseInfoController", description = "路网基础信息")
@RequestMapping("/baseInfo")
@RestController
public class CrossBaseInfoController {

    @Resource
    private BaseInfoService baseInfoService;


    @ApiOperation(value = "路口信息查询", notes = "路口信息查询", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @GetMapping(value = "/crossInfoList")
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = BaseCrossInfoPO.class),
    })
    public JsonViewObject crossInfoList() {
        List<BaseCrossInfoPO> baseCrossInfoPOS = baseInfoService.crossInfoList();
        return JsonViewObject.newInstance().success(baseCrossInfoPOS);
    }

    @ApiOperation(value = "车道信息查询", notes = "车道信息查询", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @GetMapping(value = "/laneInfoList")
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = CrossBaseLaneInfoPO.class),
    })
    public JsonViewObject laneInfoList() {
        List<CrossBaseLaneInfoPO> crossBaseLaneInfoPOS = baseInfoService.laneInfoList();
        return JsonViewObject.newInstance().success(crossBaseLaneInfoPOS);
    }

    @ApiOperation(value = "路段信息查询", notes = "路段信息查询", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @GetMapping(value = "/ridInfoList")
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = RidInfoEntity.class),
    })
    public JsonViewObject ridInfoList() {
        List<RidInfoEntity> ridInfoEntities = baseInfoService.ridInfoList();
        return JsonViewObject.newInstance().success(ridInfoEntities);
    }

    @ApiOperation(value = "转向信息查询", notes = "车道信息查询", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @GetMapping(value = "/turnInfoList")
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = CrossTurnInfoPO.class),
    })
    public JsonViewObject turnInfoList() {
        List<CrossTurnInfoPO> crossTurnInfoPOS = baseInfoService.turnInfoList();
        return JsonViewObject.newInstance().success(crossTurnInfoPOS);
    }

    @ApiOperation(value = "Link信息查询", notes = "Link信息查询", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @GetMapping(value = "/linkInfoList")
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = LinkInfoEntity.class),
    })
    public JsonViewObject linkInfoList(String rid) {
        List<LinkInfoEntity> linkInfoEntities = baseInfoService.linkInfoList(rid);
        return JsonViewObject.newInstance().success(linkInfoEntities);
    }


    @ApiOperation(value = "绿波基础信息查询", notes = "绿波基础信息查询", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @GetMapping(value = "/greenInfoList")
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = GreenwaveInfoPO.class),
    })
    public JsonViewObject greenInfoList() {
        List<GreenwaveInfoPO> greenwaveInfoPOS = baseInfoService.greenInfoList();
        return JsonViewObject.newInstance().success(greenwaveInfoPOS);
    }

    @ApiOperation(value = "绿波路段基础信息查询", notes = "绿波路段基础信息查询", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @GetMapping(value = "/greenRidInfoList")
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = GreenwaveRidPO.class),
    })
    public JsonViewObject greenRidInfoList() {
        List<GreenwaveRidPO> greenwaveRidPOS = baseInfoService.greenRidInfoList();
        return JsonViewObject.newInstance().success(greenwaveRidPOS);
    }

    @ApiOperation(value = "绿波关联路口信息查询", notes = "绿波关联路口信息查询", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @GetMapping(value = "/greenCrossInfoList")
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = GreenwaveCrossPO.class),
    })
    public JsonViewObject greenCrossInfoList() {
        List<GreenwaveCrossPO> greenwaveCrossPOS = baseInfoService.greenCrossInfoList();
        return JsonViewObject.newInstance().success(greenwaveCrossPOS);
    }
}
