package net.wanji.web.dto;

import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.util.List;

/**
 * @author Kent HAN
 * @date 2023/1/5 10:30
 */
@NoArgsConstructor
@Data
public class SaveSchemeConfigDTO {
    @ApiModelProperty(value = "路口ID", required = true)
    private String crossId;

    @ApiModelProperty(value = "配时方式 1阶段式 2环式", required = true)
    private Integer timeType;

    @ApiModelProperty(name = "当前方案ID",notes = "")
    private Integer currentSchemeId;

    private List<PhaseScheme> phaseSchemeList; // 方案列表
    @Data
    public static class PhaseScheme {
        @ApiModelProperty(value = "方案ID", required = true)
        private Integer schemeId;
        @ApiModelProperty(value = "方案号", required = true)
        private String schemeNo;
        @ApiModelProperty(value = "方案名称", required = true)
        private String name;
        @ApiModelProperty(value = "协调相位号", required = false)
        private String coordPhaseNo = "";
        @ApiModelProperty(value = "周期", required = true)
        private Integer cycle = 0;
        @ApiModelProperty(value = "相位差", required = false)
        private Integer offset = 0;
        @ApiModelProperty(value = "状态：1执行；0未执行", required = false)
        private Integer status;
        private List<RingListElement> ringList; // 环列表
        private List<PhaseListElement> specialControlModeList; // 特殊控制相位列表

    }

    @Data
    public static class RingListElement {
        @ApiModelProperty(value = "环号", required = true)
        private Integer ringNo;
        List<GroupListElement> groupList; // 组列表

    }

    @Data
    public static class GroupListElement {
        @ApiModelProperty(value = "组号", required = true)
        private Integer groupNo;
        List<PhaseListElement> phaseList; // 相位列表
    }

    @Data
    public static class PhaseListElement {
        @ApiModelProperty(value = "相位ID", required = true)
        private Integer phaseId;
        @ApiModelProperty(value = "相位号", required = true)
        private String phaseNo;
        @ApiModelProperty(value = "相位类型 1实相位 2虚相位 3伴随相位", required = true)
        private Integer phaseType;
        @ApiModelProperty(value = "最小绿灯时间", required = true)
        private Integer minGreenTime = 0;
        @ApiModelProperty(value = "最大绿灯时间", required = true)
        private Integer maxGreenTime = 0;
        @ApiModelProperty(value = "绿灯时间", required = true)
        private Integer greenTime = 0;
        @ApiModelProperty(value = "绿闪时间", required = true)
        private Integer greenFlashTime = 0;
        @ApiModelProperty(value = "黄闪时间", required = true)
        private Integer yellowFlashTime = 0;
        @ApiModelProperty(value = "红闪时间", required = true)
        private Integer redFlashTime = 0;
        @ApiModelProperty(value = "黄灯时间", required = true)
        private Integer yellowTime = 0;
        @ApiModelProperty(value = "红灯时间", required = true)
        private Integer redTime = 0;
        @ApiModelProperty(value = "是否黄闪 0否 1是", required = true)
        private Integer yellowFlash = 0;
        @ApiModelProperty(value = "是否红灯 0否 1是", required = true)
        private Integer isRed = 0;
        @ApiModelProperty(value = "是否绿灯 0否 1是", required = true)
        private Integer isGreen = 0;
        @ApiModelProperty(value = "是否绿闪 0否 1是", required = true)
        private Integer greenFlash = 0;
        @ApiModelProperty(value = "母相位号列表", required = true)
        List<String> accompanyPhaseNoList;
        private List<DirListElement> dirList; // 方向列表
    }

    @Data
    public static class DirListElement {
        @ApiModelProperty(value = "车道进口方向：1北；2东北；3东；4东南；5南；6西南；7西；8西北", required = true)
        private Integer dir;
        @ApiModelProperty(value = "是否有行人相位：0否；1是", required = true)
        private Integer hasPersonPhase = 0;
        private List<LaneListElement> laneList; // 车道列表
    }

    @Data
    public static class LaneListElement {
        @ApiModelProperty(value = "车道转向：0未知；1左转；2直行；3右转；4掉头；5直左；6直右；7左直右；8左右；9左转掉头；10直行掉头；11右转掉头；12左直掉头；13直右掉头；14左直右掉头；15左右掉头", required = true)
        private Integer direction;
        @ApiModelProperty(value = "车道类别：1机动车；2非机动车；3公交专用；4可变；5潮汐", required = true)
        private Integer laneType;
        @ApiModelProperty(value = "车道ID")
        private String laneId;
        @ApiModelProperty(value = "灯组ID")
        private Integer lightsId;
    }
}