package net.wanji.web.po;

import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import org.springframework.data.annotation.Id;

import javax.validation.constraints.NotBlank;
import java.util.Date;

/**
 * @author Kent HAN
 * @date 2022/10/27 9:49
 */
@Data
public class CrossAlarmPO {
    /** 路口编号 */
    @Id
    @ApiModelProperty(value = "路口编号")
    @NotBlank(message = "路口编号不能为空")
    // @Pattern(regexp = "^[A-za-z0-9]{11}$",message="路口编号只能包含英文、数字,必须11个字符")
    private String crossId ;

    /** 路口状态0;正常 1 失衡  2 拥堵 3 溢出 4 死锁 */
    @ApiModelProperty(name = "路口状态",notes = "0正常 1 失衡  2 拥堵 3 溢出 4 死锁")
    private String status ;

    /** 交通指数（1~10） */
    @ApiModelProperty(name = "交通指数（1~10）",notes = "")
    private Double trafficIndex;

    /** 开始时间：yyyy-MM-dd;HH;mm:ss */
    @ApiModelProperty(name = "开始时间：yyyy-MM-dd HH:mm:ss")
    private Date startTime ;

    /** 结束时间：yyyy-MM-dd;HH;mm:ss */
    @ApiModelProperty(name = "结束时间：yyyy-MM-dd HH:mm:ss")
    private Date endTime ;

    /** 持续时间（单位：分钟） */
    @ApiModelProperty(name = "持续时间（单位：分钟）",notes = "")
    private Integer duration ;

    /** 是否失衡：0;否 1 是 */
    @ApiModelProperty(name = "是否失衡",notes = "0否 1 是")
    private Integer isUnbalance ;

    /** 是否溢出：0;否 1 是 */
    @ApiModelProperty(name = "是否溢出",notes = "0否 1 是")
    private Integer isSpillover ;

    /** 是否拥堵：0;否 1 是 */
    @ApiModelProperty(name = "是否拥堵",notes = "0否 1 是")
    private Integer isCongestion ;

    /** 失衡指数 */
    @ApiModelProperty(name = "失衡指数",notes = "")
    private Double unbalanceIndex ;

    /** 溢出指数 */
    @ApiModelProperty(name = "溢出指数",notes = "")
    private Double spilloverIndex ;

    /** 拥堵指数 */
    @ApiModelProperty(name = "拥堵指数",notes = "")
    private Double congestionIndex ;

    /** 失衡时间（单位：分钟） */
    @ApiModelProperty(name = "失衡时间（单位：分钟）",notes = "")
    private Integer unbalanceTime ;

    /** 溢出时间（单位：分钟） */
    @ApiModelProperty(name = "溢出时间（单位：分钟）",notes = "")
    private Integer spilloverTime ;

    /** 拥堵时间（单位：分钟） */
    @ApiModelProperty(name = "拥堵时间（单位：分钟）",notes = "")
    private Integer congestionTime ;

    /** 路口失衡方向：1;2，3... */
    @ApiModelProperty(name = "路口失衡方向：1，2，3...")
    private String unbalanceDirs ;

    /** 路口溢出方向：1;2，3... */
    @ApiModelProperty(name = "路口溢出方向：1，2，3...")
    private String spilloverDirs ;

    /** 路口拥堵方向：1;2，3... */
    @ApiModelProperty(name = "路口拥堵方向：1，2，3...")
    private String congestionDirs ;

    /** 创建时间：yyyy-MM-dd;HH;mm:ss */
    @ApiModelProperty(name = "创建时间：yyyy-MM-dd HH:mm:ss")
    private Date gmtCreate ;

    /** 修改时间：yyyy-MM-dd;HH;mm:ss */
    @ApiModelProperty(name = "修改时间：yyyy-MM-dd",notes = "HH;mm:ss")
    private Date gmtModified ;
}
