package net.wanji.web.service;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import net.wanji.common.framework.rest.JsonViewObject;
import net.wanji.databus.dao.mapper.BaseCrossInfoMapper;
import net.wanji.databus.po.BaseCrossInfoPO;
import net.wanji.databus.po.TBaseCrossInfo;
import net.wanji.databus.vo.CrossInfoVO;
import net.wanji.web.common.enums.CrossTypeEnum;
import net.wanji.web.common.util.IdWorker;
import net.wanji.web.entity.TBaseAreaInfo;
import net.wanji.web.mapper.TBaseAreaInfoMapper;
import net.wanji.web.po.AreaTreePO;
import net.wanji.web.po.PageResultPO;
import net.wanji.web.vo.BaseCrossInfoVO;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.List;
import java.util.Map;
import java.util.Objects;
import java.util.stream.Collectors;

/**
 * <p>
 * 路口基础表 服务实现类
 * </p>
 *
 * @author wj
 * @since 2022-11-28
 */
@Service
public class CrossInfoService {

    @Autowired
    private BaseCrossInfoMapper baseCrossInfoMapper;

    @Autowired
    private TBaseAreaInfoMapper areaInfoMapper;


    /**
     * 查询
     *
     * @param crossInfoVO 查询路口管理输入参数
     */
    public JsonViewObject selectAll(CrossInfoVO crossInfoVO) {
        PageResultPO<BaseCrossInfoPO> page = new PageResultPO<>();
        Integer count = baseCrossInfoMapper.countSelectAll(crossInfoVO);
        List<BaseCrossInfoPO> list = baseCrossInfoMapper.selectAll(crossInfoVO);
        page.setPageNum(crossInfoVO.getPageNum());
        page.setPageSize(crossInfoVO.getPageSize());
        page.setTotal(count);
        page.setData(list);
        return JsonViewObject.newInstance().success(page);
    }

    /**
     * 添加
     *
     * @param crossInfoPO 增加路口管理输入参数
     */
    public JsonViewObject addOne(BaseCrossInfoVO crossInfoPO) {
        JsonViewObject jsonViewObject = JsonViewObject.newInstance().success();
        if (StringUtils.isNoneBlank(crossInfoPO.getId())) {
            TBaseCrossInfo tBaseCrossInfo = baseCrossInfoMapper.selectByPrimaryKey(crossInfoPO.getId());
            if (Objects.nonNull(tBaseCrossInfo)) {
                return jsonViewObject.fail("路口编号重复，请重新设置！");
            }
        }
        TBaseCrossInfo record = getBaseCrossInfo(crossInfoPO);
        record.setGmtCreate(new Date());
        int insert = baseCrossInfoMapper.insertSelective(record);
        if (insert > 0) {
            return jsonViewObject.success("添加成功");
        }
        return JsonViewObject.newInstance().fail("路口添加失败");
    }

    /**
     * 更新
     *
     * @param crossInfoPO 修改路口管理输入参数
     */
    public JsonViewObject updateOne(BaseCrossInfoVO crossInfoPO) {
        TBaseCrossInfo record = new TBaseCrossInfo();
        BeanUtils.copyProperties(crossInfoPO, record);
        // 如果不是信控路口，关闭优化和下发方案开关
        if (crossInfoPO.getIsSignal() == 0) {
            record.setIsStart(0);
            record.setIsSend(0);
        }
        record.setGmtModified(new Date());
        int update = baseCrossInfoMapper.updateByPrimaryKeySelective(record);
        if (update > 0) {
            return JsonViewObject.newInstance().success("修改成功");
        }
        return JsonViewObject.newInstance().fail("修改失败");
    }

    private TBaseCrossInfo getBaseCrossInfo(BaseCrossInfoVO crossInfoPO) {
        if (crossInfoPO.getId() == null || crossInfoPO.getId().trim().equals("")) {
            IdWorker idWorker = new IdWorker(0, 0);
            crossInfoPO.setId(String.valueOf(idWorker.nextId()));
        }
        if (crossInfoPO.getAreaCode() == null) {
            QueryWrapper<TBaseAreaInfo> queryWrapper = new QueryWrapper<>();
            queryWrapper.lambda().like(TBaseAreaInfo::getName, crossInfoPO.getAreaName());
            // 查询areaCode
            List<TBaseAreaInfo> tBaseAreaInfos = areaInfoMapper.selectList(queryWrapper);
            if (tBaseAreaInfos != null && tBaseAreaInfos.size() > 0) {
                crossInfoPO.setAreaCode(tBaseAreaInfos.get(0).getCode());
            }
        }
        if (crossInfoPO.getAreaName() == null) {
            QueryWrapper<TBaseAreaInfo> queryWrapper = new QueryWrapper<>();
            queryWrapper.lambda().eq(TBaseAreaInfo::getCode, crossInfoPO.getAreaCode());
            List<TBaseAreaInfo> tBaseAreaInfos = areaInfoMapper.selectList(queryWrapper);
            if (tBaseAreaInfos != null && tBaseAreaInfos.size() > 0) {
                crossInfoPO.setAreaName(tBaseAreaInfos.get(0).getName());
            }
        }
        if (crossInfoPO.getType() == null) {
            crossInfoPO.setType(CrossTypeEnum.OTHER.getCode());
        }
        if (crossInfoPO.getLevel() == null) {
            crossInfoPO.setLevel(0);
        }
        if (crossInfoPO.getIsSend() == null) {
            crossInfoPO.setIsSend(1);
        }
        if (crossInfoPO.getIsSignal() == null) {
            crossInfoPO.setIsSignal(1);
        }
        if (crossInfoPO.getIsStart() == null) {
            crossInfoPO.setIsStart(1);
        }
        if (crossInfoPO.getLocation() == null) {
            crossInfoPO.setLocation("null");
        }
        TBaseCrossInfo record = new TBaseCrossInfo();
        BeanUtils.copyProperties(crossInfoPO, record);
        record.setGmtModified(new Date());
        return record;
    }

    /**
     * 删除
     *
     * @param ids id集合
     */
    public JsonViewObject delete(List<String> ids) {
        baseCrossInfoMapper.deleteBatchIds(ids);
        return JsonViewObject.newInstance().success("删除成功");
    }


    /**
     * 区域名称下拉框
     *
     */
    public List<AreaTreePO> areaTree() {
        List<AreaTreePO> infos = areaInfoMapper.selectAreaTree();
        // 构建树
        Map<Integer, List<AreaTreePO>> parentCodeMap = infos.stream().collect(Collectors.groupingBy(AreaTreePO::getParentCode));
        for (AreaTreePO info : infos) {
            for (Integer parentCode : parentCodeMap.keySet()) {
                if (info.getAreaCode().equals(parentCode)) {
                    info.setChildren(parentCodeMap.get(parentCode));
                    break;
                }
            }
        }
        infos = infos.stream().filter(po -> po.getParentCode() != null).collect(Collectors.toList());
        return infos;
    }
}

