package net.wanji.web.task;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import net.wanji.common.framework.rest.JsonViewObject;
import net.wanji.databus.po.BaseCrossInfoPO;
import net.wanji.feign.service.UtcFeignClients;
import net.wanji.web.common.constant.Constant;
import net.wanji.web.common.util.StringUtils;
import net.wanji.web.entity.TDeviceStatusInfo;
import net.wanji.web.mapper.TDeviceStatusMapper;
import net.wanji.web.service.SituationDetectionService;
import net.wanji.web.vo.situationDetection.CommonEventAlarmOutVo;
import net.wanji.web.websocket.WebSocketServer;
import org.springframework.stereotype.Component;
import org.springframework.util.CollectionUtils;

import java.io.IOException;
import java.time.LocalDateTime;
import java.time.ZoneOffset;
import java.time.format.DateTimeFormatter;
import java.util.*;

/**
 * @author duanruiming
 * @date 2023/01/06 10:45
 */
@Component
@Slf4j
@SuppressWarnings("all")
@RequiredArgsConstructor
public class  CommonEventWarnTask {

    private final UtcFeignClients utcFeignClients;
    private final SituationDetectionService situationDetectionService;
    private final TDeviceStatusMapper tDeviceStatusMapper;

    public void pushEvenWarnData() {
        try {
            Set<WebSocketServer> events = WebSocketServer.getWebSocketSet(Constant.WEBSOCKET_TOPIC_EVENT_WARN);
            if (!CollectionUtils.isEmpty(events)) {
                log.info("告警socket连接数量：{}，告警信息：{}", events.size(), events);
                for (WebSocketServer entry : events) {
                    String userId = entry.getUserId();
                    commonEventWarnDataSend(userId);
                }
            }
        } catch (Exception e) {
            log.error("统一推送事件告警数据失败！", e);
        }
    }

    private void commonEventWarnDataSend(String userId) throws IOException {
        // 信号机故障
        JsonViewObject signalWarnData = getSignalWarnData();
        if (Objects.nonNull(signalWarnData)) {
            WebSocketServer.sendTopicInfo2All(JSONObject.toJSONString(signalWarnData), Constant.WEBSOCKET_TOPIC_EVENT_WARN);
        }
        // todo 数据中心获取路口告警
        JsonViewObject crossWarnData = getCrossWarnData();
        // todo 数据中心获取事件告警
        JsonViewObject crossEventWarnData = getCrossEventWarnData();
    }

    private JsonViewObject getCrossEventWarnData() {
        return null;
    }

    private JsonViewObject getCrossWarnData() {
        return null;
    }

    /**
     * 信号机故障告警数据
     *
     * @return
     */
    private JsonViewObject getSignalWarnData() {
        JsonViewObject jsonViewObject = null;
        try {
            List<CommonEventAlarmOutVo> results = new ArrayList<>();
            jsonViewObject = utcFeignClients.runningStatusAlarm();
            if (Objects.isNull(jsonViewObject) || jsonViewObject.getCode() != 200) {
                return jsonViewObject.fail("信号机告警UTC服务调用异常！");
            }

            LocalDateTime now = LocalDateTime.now();
            String formatNow = DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss").format(now);
            List<Map<String, Object>> content = (List<Map<String, Object>>) jsonViewObject.getContent();
            content.forEach(result -> {
                String signalId = (String) result.get("signalId");
                String crossId = (String) result.get("crossId");
                Integer currentStatus = (Integer) result.get("status");
                Integer currentFaultType = (Integer) result.get("faultType");

                String coordinate = "";
                String crossName = "";
                TDeviceStatusInfo tDeviceStatusInfo1 = new TDeviceStatusInfo();
                if (StringUtils.isNotEmpty(crossId)) {
                    BaseCrossInfoPO tBaseCrossInfo = situationDetectionService.selectCrossInfoById(crossId);
                    if (Objects.nonNull(tBaseCrossInfo)) {
                        coordinate = tBaseCrossInfo.getLocation();
                    }
                    QueryWrapper<TDeviceStatusInfo> queryWrapper = new QueryWrapper<>();
                    TDeviceStatusInfo tDeviceStatusInfo = tDeviceStatusMapper.selectOne(queryWrapper.eq("code", crossId));
                    if (Objects.nonNull(tDeviceStatusInfo)) {
                        tDeviceStatusInfo1 =tDeviceStatusInfo;
                        crossName = tDeviceStatusInfo.getName();
                    }
                }

                buildSignalWarnData(results, formatNow, signalId, currentStatus, currentFaultType, coordinate, crossName, tDeviceStatusInfo1);
            });
            // 无告警数据
            if (CollectionUtils.isEmpty(results)) {
                return null;
            }
            jsonViewObject.setTimestamp(now.toInstant(ZoneOffset.of("+8")).toEpochMilli());
            jsonViewObject.setContent(results);
        } catch (Exception e) {
            log.error("获取信号机告警数据失败", e);
        }
        return jsonViewObject;
    }

    /**
     * 构建信号机告警消息
     *
     * @param results
     * @param formatNow
     * @param signalId
     * @param currentStatus
     * @param currentFaultType
     * @param coordinate
     * @param crossName
     * @param tDeviceStatusInfo1
     */
    private static void buildSignalWarnData(List<CommonEventAlarmOutVo> results, String formatNow, String signalId, Integer currentStatus, Integer currentFaultType, String coordinate, String crossName, TDeviceStatusInfo tDeviceStatusInfo1) {
        try {
            if (SignalStatusTask.isExecuteUpdate(currentStatus, currentFaultType, tDeviceStatusInfo1)) {
                log.error("测试日志，执行信号机状态修改成功");
                CommonEventAlarmOutVo commonEventAlarmOutVo = new CommonEventAlarmOutVo();
                commonEventAlarmOutVo.setEventType(3);
                commonEventAlarmOutVo.setEventId(signalId);
                commonEventAlarmOutVo.setEventName(crossName);
                if (currentStatus == 0) {
                    commonEventAlarmOutVo.setStatus("11");
                    commonEventAlarmOutVo.setEventDesc(crossName.concat("信号机离线"));
                } else if (currentStatus == 1){
                    commonEventAlarmOutVo.setStatus(String.valueOf(0));
                    commonEventAlarmOutVo.setEventDesc(crossName.concat("信号机上线"));
                } else {
                    commonEventAlarmOutVo.setStatus(String.valueOf(currentFaultType));
                    commonEventAlarmOutVo.setEventDesc(crossName.concat("信号机故障"));
                }
                commonEventAlarmOutVo.setStartTime(formatNow);
                commonEventAlarmOutVo.setCoordinate(coordinate);
                results.add(commonEventAlarmOutVo);
                log.error("测试日志，返回结果result:{}", results);
            }
        } catch (Exception e) {
            log.error("构建信号机告警数据失败", e);
        }
    }
}
