package net.wanji.web.task;

import cn.hutool.core.collection.CollectionUtil;
import com.alibaba.fastjson.JSONObject;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import net.wanji.web.common.constant.Constant;
import net.wanji.web.kafka.ConsumerHandler;
import net.wanji.web.kafka.JNMatchResultMiniData;
import net.wanji.web.websocket.WebSocketServer;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.scheduling.concurrent.ThreadPoolTaskExecutor;
import org.springframework.stereotype.Component;
import org.springframework.util.CollectionUtils;

import javax.annotation.Resource;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;
import java.util.Objects;
import java.util.Set;
import java.util.concurrent.atomic.AtomicInteger;

/**
 * @author duanruiming
 * @date 2023/05/17 16:08
 */
@Component
@Slf4j
public class RealTimeCarTask {

    @Resource
    private ConsumerHandler consumerHandler;
    @Autowired
    @Qualifier(value = "commonThreadPoolExecutor")
    private ThreadPoolTaskExecutor commonThreadPoolExecutor;

    private static final List<TempPojo> tempList = new ArrayList<>(7);
    private static final AtomicInteger atomicInteger = new AtomicInteger(0);

    static {
        tempList.add(new TempPojo(112.967134, 28.182384));
        tempList.add(new TempPojo(112.966402, 28.182420));
        tempList.add(new TempPojo(112.964600, 28.182618));
        tempList.add(new TempPojo(112.963046, 28.182838));
        tempList.add(new TempPojo(112.963092, 28.184083));
        tempList.add(new TempPojo(112.963606, 28.188246));
        tempList.add(new TempPojo(112.967486, 28.187118));
    }

    @Scheduled(fixedRate = 2000)
    public void pushRealTimeCarInfo() {
//        threadPoolExecutor.execute(() -> {
            int i = atomicInteger.get();
            atomicInteger.incrementAndGet();
            if (i == 6) {
                atomicInteger.set(0);
            }
        Set<WebSocketServer> events = WebSocketServer.getWebSocketSet(Constant.WEBSOCKET_TOPIC_CAR_TRAIL_INFO);
        if (CollectionUtil.isEmpty(events)) {
            return;
        }
        for (WebSocketServer socketServer : events) {
            String userId = socketServer.getUserId();
            String picLicense = null;
            if (StringUtils.isNotBlank(userId)) {
                picLicense = userId.substring(0, 7);
            }
            JNMatchResultMiniData jnMatchResultMiniData = consumerHandler.getTopicMessage("CSMatchResultMiniData_0");
            if (Objects.nonNull(jnMatchResultMiniData)) {
                List<JNMatchResultMiniData.E1FrameParticipant> list = jnMatchResultMiniData.getE1FrameParticipant();
                if (!CollectionUtils.isEmpty(list)) {
                    for (JNMatchResultMiniData.E1FrameParticipant e1FrameParticipant : list) {
                        int id = e1FrameParticipant.getId();
                        String license = e1FrameParticipant.getPicLicense();
                        // 测试车牌；京WJ0001
                        license = "京WJ0001";
                        if (3573 == e1FrameParticipant.getId() && StringUtils.equals(license, picLicense)) {
                            TempPojo tempPojo = RealTimeCarTask.tempList.get(i);
                            e1FrameParticipant.setLongitude(tempPojo.getLongitude());
                            e1FrameParticipant.setLatitude(tempPojo.getLatitude());
                            e1FrameParticipant.setPicLicense(license);
                            try {
                                socketServer.sendMessage(JSONObject.toJSONString(e1FrameParticipant));
                            } catch (IOException e) {
                                throw new RuntimeException(e);
                            }
                        }
                    }
                }
            }
        }
//        });
    }

    @Data
    @AllArgsConstructor
    static class TempPojo {
        private Double longitude;
        private Double latitude;
    }

}
