package net.wanji.web.task;

import lombok.extern.slf4j.Slf4j;
import net.wanji.common.framework.rest.JsonViewObject;
import net.wanji.databus.bo.CrossIdBO;
import net.wanji.databus.dao.mapper.BaseCrossInfoMapper;
import net.wanji.databus.po.BaseCrossInfoPO;
import net.wanji.databus.vo.CrossInfoVO;
import net.wanji.web.service.impl.PlanSendServiceImpl;
import org.apache.commons.collections.CollectionUtils;
import org.joda.time.LocalDateTime;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.scheduling.annotation.Scheduled;

import java.util.ArrayList;
import java.util.List;

/**
 * @author zhouleilei
 * 信号机同步任务
 * @date 2025/02/18 11:35
 */
//@Component
//@RequiredArgsConstructor
@Slf4j
public class SignalSynchronizationTask {

    @Autowired
    private BaseCrossInfoMapper baseCrossInfoMapper;
    @Autowired
    private  PlanSendServiceImpl planSendService;
    @Scheduled(fixedRate = 1 * 1000)
    public void syncSignalStatus() {
        log.info("===开始同步，当前时间：{}", LocalDateTime.now());
        CrossInfoVO crossInfoVO = new CrossInfoVO();
        crossInfoVO.setIsSignal(1);
        List<BaseCrossInfoPO> baseCrossInfoPOS = baseCrossInfoMapper.selectAll(crossInfoVO);
        List<String> errorCrossIds = new ArrayList<>();
        List<String> okCrossIds = new ArrayList<>();
        if (CollectionUtils.isNotEmpty(baseCrossInfoPOS)) {
            baseCrossInfoPOS.forEach(po -> {
                CrossIdBO crossIdBO = new CrossIdBO();
                crossIdBO.setCrossId(po.getId());
                try {
                    JsonViewObject jsonViewObject = planSendService.syncScheme(crossIdBO);
                    if (jsonViewObject.getCode() == 200) {
                        okCrossIds.add(po.getId());
                        log.info("路口同步成功,路口号:{}，时间:{}",po.getId(),LocalDateTime.now());
                    } else {
                        errorCrossIds.add(po.getId());
                        log.error("路口同步失败路口号:{}，时间:{}",po.getId(),LocalDateTime.now());

                    }
                } catch (Exception e) {
                    throw new RuntimeException(e);
                }
            });
        }
        log.info("===同步完成，当前时间：{}，成功路口：{}，失败路口：{}", LocalDateTime.now(), okCrossIds, errorCrossIds);
        System.exit(0);


    }
}
